@@ -14,6 +14,11 @@
  *    OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  ******************************************************************************/
 
+#ifdef _WIN32
+/* Disable deprecation warnings */
+#pragma warning(disable: 4996)
+#endif
+
 #include <alljoyn/controlpanel/Property.h>
 #include <alljoyn/controlpanel/ControlPanelService.h>
 #include "../ControlPanelConstants.h"
@@ -245,6 +250,7 @@ QStatus Property::setGetValue(const CPSTime& (*getTimeValue)())
 
 QStatus Property::fillPropertyValueArg(MsgArg& val, uint16_t languageIndx)
 {
+    QCC_UNUSED(languageIndx);
     QStatus status = ER_BUS_NO_SUCH_PROPERTY;
 
     if (!m_GetValue.getBoolValue) {
@@ -405,6 +411,7 @@ QStatus Property::fillOptParamsArg(MsgArg& val, uint16_t languageIndx)
 
 QStatus Property::setPropertyValue(MsgArg& val, uint16_t languageIndx)
 {
+    QCC_UNUSED(languageIndx);
     QStatus status;
 
     switch (m_PropertyType) {
