@@ -14,6 +14,11 @@
  *    OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  ******************************************************************************/
 
+#ifdef _WIN32
+/* Disable deprecation warnings */
+#pragma warning(disable: 4996)
+#endif
+
 #include <alljoyn/about/AboutServiceApi.h>
 #include <alljoyn/about/AnnouncementRegistrar.h>
 #include <alljoyn/notification/NotificationService.h>
