@@ -15,6 +15,12 @@
  ******************************************************************************/
 
 #include <signal.h>
+
+#ifdef _WIN32
+/* Disable deprecation warnings */
+#pragma warning(disable: 4996)
+#endif
+
 #include <SrpKeyXListener.h>
 #include <CommonSampleUtil.h>
 #include <AboutDataStore.h>
@@ -87,12 +93,13 @@ ControlPanelControllee* controlPanelControllee = NULL;
 #endif
 
 static void CDECL_CALL SigIntHandler(int sig) {
+    QCC_UNUSED(sig);
     s_interrupt = true;
 }
 
 static void daemonDisconnectCB()
 {
-    QCC_DbgHLPrintf(("Received daemonDisconnectCB"));
+    QCC_LogMsg(("Received daemonDisconnectCB"));
     s_restart = true;
 }
 
@@ -278,7 +285,7 @@ QStatus fillAboutData(AboutData* aboutdata)
 }
 
 int main(int argc, char**argv, char**envArg) {
-
+    QCC_UNUSED(envArg);
     QStatus status = ER_OK;
 
     // Initialize AllJoyn
@@ -528,7 +535,7 @@ start:
     cleanup();
 
     if (s_restart) {
-        QCC_DbgHLPrintf(("restarting..."));
+        QCC_LogMsg(("restarting..."));
         s_restart = false;
         goto start;
     }
